
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the mq_config module](#installing-the-mq_config-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to configure and manage IBM MQ messaging software. It is part of our family of Puppet modules to install and manage IBM messaging middleware. Besides the [`mq_config`](https://www.enterprisemodules.com/shop/products/ibm-mq-config) module, this family also contains:

- [`mq_install`](https://www.enterprisemodules.com/shop/products/ibm-mq-install) to install the MQ software
- [`iib_config`](https://www.enterprisemodules.com/shop/products/ibm-iib-config) to manage and configure IBM Integration Bus software
- [`iib_install`](https://www.enterprisemodules.com/shop/products/ibm-iib_install) to install IBM Integration Bus software

## Experience the Power of Puppet for IBM MQ

Installing IBM MQ software and managing your IBM MQ configuration can be hard. With Puppet at your side, you get super-powers when installing and managing IBM MQ. If you want to play and experiment with this [please take a look at our playgrounds](https://www.enterprisemodules.com/playgrounds#mq). 

[![Experience the Power](https://raw.githubusercontent.com/enterprisemodules/public_images/master/superpowers-33-blanc.jpg)](https://www.enterprisemodules.com/playgrounds#mq)

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. You can [request a **FREE** trial license here](https://www.enterprisemodules.com/sign-up-for-free-trial)

Check the [License](https://forge.puppet.com/enterprisemodules/mq_config/license) for details.

## Description

Our `mq_config` module allows you to configure and manage almost everything you'd want to manage on of an IBM MQ installation. The module allows you to manage:

- [mq_authentication_info](https://www.enterprisemodules.com/docs/mq_config/mq_authentication_info.htmle)
- [mq_authorization](https://www.enterprisemodules.com/docs/mq_config/mq_authorization.htmle)
- [mq_certificate](https://www.enterprisemodules.com/docs/mq_config/mq_certificate.htmle)
- [mq_certificate_file](https://www.enterprisemodules.com/docs/mq_config/mq_certificate_file.htmle)
- [mq_channel](https://www.enterprisemodules.com/docs/mq_config/mq_channel.htmle)
- [mq_channel_authentication](https://www.enterprisemodules.com/docs/mq_config/mq_channel_authentication.htmle)
- [mq_key_db](https://www.enterprisemodules.com/docs/mq_config/mq_key_db.htmle)
- [mq_listener](https://www.enterprisemodules.com/docs/mq_config/mq_listener.htmle)
- [mq_manager](https://www.enterprisemodules.com/docs/mq_config/mq_manager.htmle)
- [mq_queue](https://www.enterprisemodules.com/docs/mq_config/mq_queue.htmle)
- [mq_subscription](https://www.enterprisemodules.com/docs/mq_config/mq_subscription.htmle)
- [mq_topic](https://www.enterprisemodules.com/docs/mq_config/mq_topic.htmle)
- [mq_web](https://www.enterprisemodules.com/docs/mq_config/mq_web.htmle)

Check [here](https://www.enterprisemodules.com/docs/mq_config/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`mq_config`](https://www.enterprisemodules.com/shop/products/puppet-mq_config-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- IBM MQ 8 or 9 installation.
- A valid License from IBM to use this software.
- A valid entitlement for this module by Enterprise Modules.
- Runs on most Linux systems.
- This module supports both Windows and Linux

### Installing the mq_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/mq_config'               ,'1.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-mq_config
```

## Usage

Building a total MQ setup requires quite some work. To help you, we have built some examples:
- [MQ only example](https://github.com/enterprisemodules/simple_mq_demo)
- [MQ and IIB example](https://github.com/enterprisemodules/simple_mqiib_demo)

Thes repos contain examples of how you can install and configure a basic MQ setup. 


## Reference

Here you can find some more information regarding this puppet module:

- [The MQ config documentation](https://www.enterprisemodules.com/docs/mq_config/description.html)
- [The product announcement](https://www.enterprisemodules.com/news/2017/05/IBM-modules-with-virtualsciences/)

Here is a list of related blog posts:
- [Introducing the IBM MQ Puppet module](https://www.enterprisemodules.com/blog/2017/05/introducing-mq-module/)

Some example code:
- [Simple MQ demo](https://github.com/enterprisemodules/simple_mq_demo)
- [MQ and IIB demo](https://github.com/enterprisemodules/simple_mqiib_demo)


## Limitations

This module runs most Linux versions. It requires a puppet version higher than 4. Contact us of you need to run this module on other flavors of UNIX. We can work together with you to make it work.