# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Resource types

* [`mq_authentication_info`](#mq_authentication_info): This resource allows you to manage MQ authorization Information Objects.  Here is an example on how you should use this:      mq_authenticati
* [`mq_authorization`](#mq_authorization): This resource allows you to manage a MQ autorizations.  Here is an example on how you should use this:      mq_authorization { "group/mymqgro
* [`mq_certificate`](#mq_certificate): This resource allows you to manage SSL Certificates for MQ in a database.  It allows multiple operations:  1) Adding a certificate from an as
* [`mq_certificate_file`](#mq_certificate_file): Extracts individual certificates from a certificate key database.  Depending on the value f the `type` parameter, different actions will be d
* [`mq_channel`](#mq_channel): This resource allows you to manage a MQ Channel.  Here is an example on how you should use this with the CHLTYPE in the name:        mq_chann
* [`mq_channel_authentication`](#mq_channel_authentication): This resource allows you to manage a MQ Channel authenticatio record.  Here is an example on how you should use this:        mq_channel_authe
* [`mq_key_db`](#mq_key_db): This resource allows you to manage a MQ key database.  Here is an example on how you should use this:      mq_key_db {'/var/mqm/keys/test_db_
* [`mq_listener`](#mq_listener): This resource allows you to manage a MQ listener.  Here is an example on how you should use this:     mq_listener { 'IIB10QM/SYSTEM.DEFAULT.L
* [`mq_manager`](#mq_manager): This resource allows you to manage a MQ queue manager.  Here is an example on how you should use this:      mq_manager { 'QM1':       ensure 
* [`mq_queue`](#mq_queue): This resource allows you to manage a MQ queue.  Here is an example on how you should use this with QTYPE in the name:      mq_queue { 'QM1/QL
* [`mq_subscription`](#mq_subscription): This resource allows you to manage a MQ topic.  Here is an example on how you should use this:      mq_subscription { 'QUEUENAME/SUBNAME':   
* [`mq_topic`](#mq_topic): This resource allows you to manage a MQ topic.  Here is an example on how you should use this:      mq_topic { 'QM1/EM_TEST_TOPIC':       ens
* [`mq_web`](#mq_web): This resource allows you to manage the MQ Web package. This is a singleton resource. So there is always only one resource available on the sy

### Functions

* [`mq_config::is_standby`](#mq_configis_standby): See the file "LICENSE" for the full license governing this code.   Function to fetch the fact mq_managers and based on that information decid
* [`mq_config::qmgrs_in`](#mq_configqmgrs_in): See the file "LICENSE" for the full license governing this code.   Function to fetch the fact mq_managers and based on that information decid
* [`mq_config::resources_for`](#mq_configresources_for): See the file "LICENSE" for the full license governing this code.   Function to fetch the fact mq_managers and based on that information decid

### Tasks

* [`manager`](#manager): Allows get the status, create or remove an MQ Queue manager
* [`queue`](#queue): Allows get the status, create or remove MQ Queue
* [`topic`](#topic): Allows get the status, create or remove MQ topic

## Resource types

### <a name="mq_authentication_info"></a>`mq_authentication_info`

This resource allows you to manage MQ authorization Information Objects.

Here is an example on how you should use this:

    mq_authentication_info { 'QM1/CRLLDAP/MY_LDAP':
      ensure   => 'present',
    }

#### Properties

The following properties are available in the `mq_authentication_info` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_authentication_info` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_authentication_info` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="mq_authorization"></a>`mq_authorization`

This resource allows you to manage a MQ autorizations.

Here is an example on how you should use this:

    mq_authorization { "group/mymqgroup->MYQM1/qmgr/self":
      ensure    => 'present',
      authority => ['allmqi', 'dlt', 'chg', 'dsp', 'ctrl', 'system'],
    }

#### Properties

The following properties are available in the `mq_authorization` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_authorization` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_authorization` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="mq_certificate"></a>`mq_certificate`

This resource allows you to manage SSL Certificates for MQ in a database.

It allows multiple operations:

1) Adding a certificate from an ascii of binary file
2) Importing a labeled certificate from an other certificate database
3) Creating a self signed certificate


## Option 1: Adding a certificate from an ascii of binary file

Puppet uses this action when the `source` parameter is specified and the specified `source_type` is either
`ascii` or `binary`. Here is an example on how to use this:

    mq_certificate {'/var/mqm/keys/test_db_2.kdb:my_label_1':
      ensure          => 'present',
      password        => 'verysecret',
      source          => '/var/mqm/keys/my_label_2.ascii',
      source_type     => 'ascii',
    }

## Option 2: Importing a labeled certificate from an other certificate database

Puppet uses this action when the `source` parameter is specified and the specified `source_type` is:

- cms
- kdb
- pkcs12
- p12
- pkcs7
- pem

Here is an example on how to use this:

    mq_certificate {'/var/mqm/keys/test_db_2.kdb:my_label_1':
      ensure          => 'present',
      password        => 'verysecret',
      source          => '/var/mqm/keys/my_label_1.p12',
      source_type     => 'p12',
      source_label    => 'my_label_1',
      source_password => 'verysecret',
    }

## Option 3: Creating a self signed certificate.

When no source value is given, Puppet creates a self signed cerificate withe the specified label inside
of the certificate database. Here is an example on how that works:

    mq_certificate {'/var/mqm/keys/test_db_1.kdb:my_label_1':
      ensure             => 'present',
      password           => 'verysecret',
      distinguished_name => 'cn=bert.....',
    }

#### Properties

The following properties are available in the `mq_certificate` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_certificate` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_certificate` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="mq_certificate_file"></a>`mq_certificate_file`

Extracts individual certificates from a certificate key database.

Depending on the value f the `type` parameter, different actions will be done.

- When the type is either `ascii` of `binary` a certificate file will be created
- When the type is one of: `cms`,`kdb`,`pkcs12`,`p12`,`pkcs7`,`pem` a certificate
  database of the specified type will be created and the certificate with the specified
  label will be added to it.

Here is an example on how you can use this:

    mq_certificate_file {'/var/mqm/keys/my_label_1.p12':
      ensure          => 'present',
      ource_type      => 'p12',
      key_db          => '/var/mqm/keys/test_db_1.kdb',
      label           => 'my_label_1',
      type            => 'p12',
      password        => 'verysecret',
      target_password => 'verysecret',
    }

#### Properties

The following properties are available in the `mq_certificate_file` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_certificate_file` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_certificate_file` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

### <a name="mq_channel"></a>`mq_channel`

This resource allows you to manage a MQ Channel.

Here is an example on how you should use this with the CHLTYPE in the name:

      mq_channel { 'QM1/RCVR/EM_TEST_CHANNEL':
        ensure   => 'present',
        comphdr  => 'NONE',
        compmsg  => 'NONE',
        hbint    => '320',
        kaint    => 'AUTO',
        maxmsgl  => '4194304',
        monchl   => 'QMGR',
        npmspeed => 'FAST',
        seqwrap  => '999999999',
        sslcauth => 'REQUIRED',
        statchl  => 'QMGR',
        trptype  => 'TCP',
        usedlq   => 'YES',
      }

Here is an deprecated example on how you should use this:

      mq_channel { 'QM1/EM_TEST_CHANNEL':
        ensure   => 'present',
        chltype  => 'RCVR',
        comphdr  => 'NONE',
        compmsg  => 'NONE',
        hbint    => '320',
        kaint    => 'AUTO',
        maxmsgl  => '4194304',
        monchl   => 'QMGR',
        npmspeed => 'FAST',
        seqwrap  => '999999999',
        sslcauth => 'REQUIRED',
        statchl  => 'QMGR',
        trptype  => 'TCP',
        usedlq   => 'YES',
      }

#### Properties

The following properties are available in the `mq_channel` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_channel` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_channel` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="mq_channel_authentication"></a>`mq_channel_authentication`

This resource allows you to manage a MQ Channel authenticatio record.

Here is an example on how you should use this:

      mq_channel_authentication { 'QM1/EM_TEST_CHANNEL':
        ensure   => 'present',
          ...
      }

When used for `ADDRESMAP` records the syntax is:

    mq_channel_authentication { 'QM1/ADRESSMAP/ADMIN/10.2.248.*':
      ensure   => 'present',
      mcauser  => 'my_user',
    }

#### Properties

The following properties are available in the `mq_channel_authentication` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_channel_authentication` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_channel_authentication` resource. You will seldom need to specify this ---
Puppet will usually discover the appropriate provider for your platform.

### <a name="mq_key_db"></a>`mq_key_db`

This resource allows you to manage a MQ key database.

Here is an example on how you should use this:

    mq_key_db {'/var/mqm/keys/test_db_1.kdb':
      ensure   => 'present',
      stashed  => true,
      password => 'verysecret'
    }

#### Properties

The following properties are available in the `mq_key_db` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_key_db` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_key_db` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="mq_listener"></a>`mq_listener`

This resource allows you to manage a MQ listener.

Here is an example on how you should use this:
    mq_listener { 'IIB10QM/SYSTEM.DEFAULT.LISTENER.TCP':
      ensure  => 'present',
      backlog => '0',
      control => 'MANUAL',
      port    => '0',
      trptype => 'TCP',
    }

#### Properties

The following properties are available in the `mq_listener` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_listener` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_listener` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="mq_manager"></a>`mq_manager`

This resource allows you to manage a MQ queue manager.

Here is an example on how you should use this:

    mq_manager { 'QM1':
      ensure   => 'present',
      acctcono => 'DISABLED',
      acctint  => '1800',
      acctmqi  => 'OFF',
      acctq    => 'OFF',
      activrec => 'MSG',
      actvcono => 'DISABLED',
      actvtrc  => 'OFF',
      authorev => 'DISABLED',
      ccsid    => '1208',
      certlabl => 'ibmwebspheremqqm1',
      certvpol => 'ANY',
      chad     => 'DISABLED',
      chadev   => 'DISABLED',
      chlauth  => 'ENABLED',
      chlev    => 'DISABLED',
      clwllen  => '100',
      clwlmruc => '999999999',
      clwluseq => 'LOCAL',
      cmdev    => 'DISABLED',
      configev => 'DISABLED',
      connauth => 'SYSTEM.DEFAULT.AUTHINFO.IDPWOS',
      defclxq  => 'SCTQ',
      inhibtev => 'DISABLED',
      ipaddrv  => 'IPV4',
      localev  => 'DISABLED',
      loggerev => 'DISABLED',
      markint  => '5000',
      maxhands => '256',
      maxmsgl  => '4194304',
      maxpropl => 'NOLIMIT',
      maxumsgs => '10000',
      monacls  => 'QMGR',
      monchl   => 'OFF',
      monq     => 'OFF',
      perfmev  => 'DISABLED',
      psclus   => 'ENABLED',
      psmode   => 'ENABLED',
      psnpmsg  => 'DISCARD',
      psnpres  => 'NORMAL',
      psrtycnt => '5',
      pssyncpt => 'IFPER',
      remoteev => 'DISABLED',
      revdns   => 'ENABLED',
      routerec => 'MSG',
      schinit  => 'QMGR',
      scmdserv => 'QMGR',
      sslev    => 'DISABLED',
      sslfips  => 'NO',
      sslkeyr  => '/var/mqm/qmgrs/QM1/ssl/key',
      sslrkeyc => '0',
      statacls => 'QMGR',
      statchl  => 'OFF',
      statint  => '1800',
      statmqi  => 'OFF',
      statq    => 'OFF',
      status   => 'Running',
      strstpev => 'ENABLED',
      suiteb   => 'NONE',
      treelife => '1800',
      trigint  => '999999999',
    }

#### Properties

The following properties are available in the `mq_manager` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_manager` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_manager` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="mq_queue"></a>`mq_queue`

This resource allows you to manage a MQ queue.

Here is an example on how you should use this with QTYPE in the name:

    mq_queue { 'QM1/QLOCAL/EM_TEST':
      ensure   => 'present',
      acctq    => 'QMGR',
      bothresh => '0',
      clwlprty => '4',
      clwlrank => '1',
      clwluseq => 'QMGR',
      defbind  => 'OPEN',
      defpresp => 'SYNC',
      defprty  => '0',
      defpsist => 'NO',
      defreada => 'NO',
      defsopt  => 'SHARED',
      distl    => 'NO',
      get      => 'ENABLED',
      maxdepth => '5000',
      maxmsgl  => '4194304',
      monq     => 'QMGR',
      msgdlvsq => 'PRIORITY',
      npmclass => 'NORMAL',
      propctl  => 'COMPAT',
      put      => 'ENABLED',
      qdepthhi => '80',
      qdepthlo => '20',
      qdphiev  => 'DISABLED',
      qdploev  => 'DISABLED',
      qdpmaxev => 'ENABLED',
      qsvciev  => 'NONE',
      qsvcint  => '999999999',
      retintvl => '999999999',
      scope    => 'QMGR',
      statq    => 'QMGR',
      trigdpth => '1',
      trigmpri => '0',
      trigtype => 'FIRST',
      usage    => 'NORMAL',
    }

Here is an deprecated example on how you should use this:

    mq_queue { 'QM1/EM_TEST':
      ensure   => 'present',
      acctq    => 'QMGR',
      bothresh => '0',
      clwlprty => '4',
      clwlrank => '1',
      clwluseq => 'QMGR',
      defbind  => 'OPEN',
      defpresp => 'SYNC',
      defprty  => '0',
      defpsist => 'NO',
      defreada => 'NO',
      defsopt  => 'SHARED',
      distl    => 'NO',
      get      => 'ENABLED',
      maxdepth => '5000',
      maxmsgl  => '4194304',
      monq     => 'QMGR',
      msgdlvsq => 'PRIORITY',
      npmclass => 'NORMAL',
      propctl  => 'COMPAT',
      put      => 'ENABLED',
      qdepthhi => '80',
      qdepthlo => '20',
      qdphiev  => 'DISABLED',
      qdploev  => 'DISABLED',
      qdpmaxev => 'ENABLED',
      qsvciev  => 'NONE',
      qsvcint  => '999999999',
      qtype    => 'QLOCAL',
      retintvl => '999999999',
      scope    => 'QMGR',
      statq    => 'QMGR',
      trigdpth => '1',
      trigmpri => '0',
      trigtype => 'FIRST',
      usage    => 'NORMAL',
    }

#### Properties

The following properties are available in the `mq_queue` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_queue` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_queue` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="mq_subscription"></a>`mq_subscription`

This resource allows you to manage a MQ topic.

Here is an example on how you should use this:

    mq_subscription { 'QUEUENAME/SUBNAME':
      ensure   => 'present',
      topicstr => 'b_topic',
      dest     => 'QUEUENAME',
    }

    mq_subscription {'QM1/SUB1':
      ensure   => 'present',
      dest     => 'SYSTEM.DEFAULT.REMOTE.QUEUE',
      topicstr => 'SYSTEM.DEFAULT.TOPIC'
    }

#### Properties

The following properties are available in the `mq_subscription` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_subscription` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_subscription` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="mq_topic"></a>`mq_topic`

This resource allows you to manage a MQ topic.

Here is an example on how you should use this:

    mq_topic { 'QM1/EM_TEST_TOPIC':
      ensure   => 'present',
      topicstr => 'b_topic',
      defprty  => '5',
      defpsist => 'ASPARENT',
      dursub   => 'ASPARENT',
      mcast    => 'ASPARENT',
      npmsgdlv => 'ASPARENT',
      pmsgdlv  => 'ASPARENT',
      proxysub => 'FIRSTUSE',
      pub      => 'ASPARENT',
      pubscope => 'ASPARENT',
      sub      => 'ASPARENT',
      subscope => 'ASPARENT',
      ttype    => 'LOCAL',
      usedlq   => 'ASPARENT',
      wildcard => 'PASSTHRU',
    }

#### Properties

The following properties are available in the `mq_topic` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_topic` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_topic` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

### <a name="mq_web"></a>`mq_web`

This resource allows you to manage the MQ Web package. This is a singleton resource.
So there is always only one resource available on the system and it is called `mqweb`.
Here is an example on how you should use this:

    mq_web { 'mqweb':
      ensure                                   => 'present',
      http_host                                => 'localhost',
      http_port                                => -1,
      https_port                               => 9443,
      ltpa_cookie_name                         => 'LtpaToken2_${env.MQWEB_LTPA_SUFFIX}',
      ltpa_expiration                          => 120,
      max_msg_trace_file_size                  => 200,
      max_msg_trace_files                      => 5,
      max_trace_file_size                      => 20,
      max_trace_files                          => 10,
      mq_console_autostart                     => true,
      mq_rest_autostart                        => false,
      mq_rest_cors_max_age_in_seconds          => 0,
      mq_rest_csrf_validation                  => true,
      mq_rest_gateway_enabled                  => true,
      mq_rest_messaging_enabled                => true,
      mq_rest_mft_enabled                      => false,
      mq_rest_mft_reconnect_timeout_in_minutes => 30,
      mq_rest_request_timeout                  => 30,
      secure_ltpa                              => true,
      status                                   => 'stopped',
      trace_spec                               => '*=info',
    }

#### Properties

The following properties are available in the `mq_web` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `mq_web` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `mq_web` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

## Functions

### <a name="mq_configis_standby"></a>`mq_config::is_standby`

Type: Ruby 4.x API

See the file "LICENSE" for the full license governing this code.


Function to fetch the fact mq_managers and based on that information
decide if the specfied queue manager is running in standby mode or not.

#### `mq_config::is_standby(String $manager)`

See the file "LICENSE" for the full license governing this code.


Function to fetch the fact mq_managers and based on that information
decide if the specfied queue manager is running in standby mode or not.

Returns: `Any`

##### `manager`

Data type: `String`



### <a name="mq_configqmgrs_in"></a>`mq_config::qmgrs_in`

Type: Ruby 4.x API

See the file "LICENSE" for the full license governing this code.


Function to fetch the fact mq_managers and based on that information
decide if the specfied queue manager is running in standby mode or not.

#### `mq_config::qmgrs_in(Hash $resources)`

See the file "LICENSE" for the full license governing this code.


Function to fetch the fact mq_managers and based on that information
decide if the specfied queue manager is running in standby mode or not.

Returns: `Array`

##### `resources`

Data type: `Hash`



### <a name="mq_configresources_for"></a>`mq_config::resources_for`

Type: Ruby 4.x API

See the file "LICENSE" for the full license governing this code.


Function to fetch the fact mq_managers and based on that information
decide if the specfied queue manager is running in standby mode or not.

#### `mq_config::resources_for(Hash[String,Hash] $resources, String $manager)`

See the file "LICENSE" for the full license governing this code.


Function to fetch the fact mq_managers and based on that information
decide if the specfied queue manager is running in standby mode or not.

Returns: `Any`

##### `resources`

Data type: `Hash[String,Hash]`



##### `manager`

Data type: `String`



## Tasks

### <a name="manager"></a>`manager`

Allows get the status, create or remove an MQ Queue manager

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Optional[Enum['list', 'status','create','remove']]`

The action you want to execute

##### `queue_manager_name`

Data type: `Optional[String[1]]`

The name of the queue manager to use.

##### `properties`

Data type: `Optional[Hash]`

The properties to use when create a queue manager

### <a name="queue"></a>`queue`

Allows get the status, create or remove MQ Queue

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Optional[Enum['list', 'status','create','remove']]`

The action you want to execute

##### `queue_name`

Data type: `Optional[String[1]]`

The name of the queue to use.

##### `properties`

Data type: `Optional[Hash]`

The properties to use when create a queue

### <a name="topic"></a>`topic`

Allows get the status, create or remove MQ topic

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Optional[Enum['list', 'status','create','remove']]`

The action you want to execute

##### `topic_name`

Data type: `Optional[String[1]]`

The name of the topic to use.

##### `properties`

Data type: `Optional[Hash]`

The properties to use when create a topic

