#
# See the file "LICENSE" for the full license governing this code.
#
#
# Function to fetch the fact mq_managers and based on that information
# decide if the specfied queue manager is running in standby mode or not.
#
Puppet::Functions.create_function('mq_config::is_standby') do
  dispatch :is_standby do
    param 'String', :manager
    # return_type 'Boolean' TODO: Wait until the Puppet version supporting this, is mainstream
  end

  # rubocop: disable Naming/PredicateName
  def is_standby(manager)
    variable = 'mq_managers'
    if variable_exists?(variable)
      fact_value = closure_scope.lookupvar("::#{variable}")
      value = fact_value.find { |qm| qm['name'] == manager }
      return true if value && value['state'] == 'Running as standby'

      return false
    end
    false
  end
  # rubocop: enable Naming/PredicateName

  # Check if the variable exists without generating a warning
  def variable_exists?(var)
    closure_scope.to_hash.key?(var)
  end
end
