#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_authentication_info) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage MQ authorization Information Objects.

  Here is an example on how you should use this:

      mq_authentication_info { 'QM1/CRLLDAP/MY_LDAP':
        ensure   => 'present',
      }

  DESC

  ensurable

  to_get_raw_resources do
    information = running_queue_managers.flat_map do |qmgr, _status|
      output = runmqsc('display authinfo(*) all', :qmgr => qmgr).
               to_s.
               split(/AMQ8566.*: Display authentication information details.\n/)
      output.shift
      output.collect { |e| [qmgr.to_s, e.to_s] }
    end
    information.collect { |e| [:qmgr, :output].zip(e).to_h }
  end

  on_create do
    when_running { [:runmqsc, "define authinfo(#{object_name}) authtype(#{authentication_type}) #{password_string}", { :qmgr => qmgr }] }
  end

  on_modify do
    when_running { [:runmqsc, "alter authinfo(#{object_name}) authtype(#{authentication_type})", { :qmgr => qmgr }] }
  end

  on_destroy do
    when_running { [:runmqsc, "delete authinfo(#{object_name})", { :qmgr => qmgr }] }
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :qmgr, :authentication_type, :object_name]])

  parameter :name
  parameter :qmgr
  parameter :authentication_type
  parameter :object_name

  property  :adoptctx
  property  :authenmd
  property  :authormd
  property  :basedng
  property  :basednu
  property  :chckclnt
  property  :chcklocl
  property  :classgrp
  property  :classusr
  property  :conname
  property  :descr
  property  :faildlay
  property  :findgrp
  property  :grpfield
  property  :ldappwd
  property  :ldapuser
  property  :like
  property  :nestgrp
  property  :ocspurl
  property  :seccomm
  property  :shortusr
  property  :usrfield

  def password_string
    return '' if ldappwd.nil?

    "ldappwd('#{ldappwd}')"
  end
end
