#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:chckclnt, :parent => PuppetX::EnterpriseModules::Mq::AuthInfoProperty) do
  desc <<-DESC
  This attribute determines the authentication requirements for client applications, and is valid only for an AUTHTYPE of IDPWOS or IDPWLDAP. The possible values are:

  - **NONE** No user ID and password checks are made. If any user ID or password is supplied by a client application, the credentials are ignored.
  - **OPTIONAL** Client applications are not required to provide a user ID and password. Any applications that do provide a user ID and password in the MQCSP structure have them authenticated by the queue manager against the password store indicated by the AUTHTYPE. The connection is only allowed to continue if the user ID and password are valid. This option might be useful during migration, for example.
  - **REQUIRED** All client applications must provide a user ID and password in the MQCSP structure. This user ID and password is authenticated by the queue manager against the password store indicated by the AUTHTYPE. The connection will only be allowed to continue if the user ID and password are valid.
  - **REQDADM** All client applications using a privileged user ID must provide a user ID and password in the MQCSP structure. Any locally bound applications using a non-privileged user ID are not required to provide a user ID and password and are treated as with the OPTIONAL setting. Any provided user ID and password are authenticated by the queue manager against the password store indicated by the AUTHTYPE. The connection is only allowed to continue if the user ID and password are valid.

  **Note**
  The REQDADM value for the CHCKCLNT attribute is irrelevant if the authentication type is LDAP. This is because there is no concept of privileged user ID when using LDAP user accounts. LDAP user accounts and groups must be assigned permission explicitly.
  DESC
  newvalues('NONE', 'OPTIONAL', 'REQUIRED', 'REQDADM')
  data_type("Optional[Enum['NONE', 'OPTIONAL', 'REQUIRED', 'REQDADM']]")
end
