#
# See the file "LICENSE" for the full license governing this code.
#

newparam(:name) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESC
    The full name of the object which security you want to manage.
    The full name constists of the name of the Queue manager, a slash and then the
    name of the object. Here is an example:

        QMGR1/MY.FIRST.CHANNEL

    This is a puppet parameter and not a managed property. Therefor it is only used during creation of the resource. Changes to this parameter in your manifest, do **NOT** result in modifications on the system.
  DESC
  data_type('Optional[String[1]]')
  isnamevar

  to_translate_to_resource do |raw_resource|
    qmgr                = raw_resource[:qmgr]
    object_name         = raw_resource[:output].scan(/AUTHINFO\((\S+)\)/).flatten.first
    authentication_type = raw_resource[:output].scan(/AUTHTYPE\((\S+)\)/).flatten.first
    "#{qmgr}/#{authentication_type}/#{object_name}"
  end
end
