#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_authorization) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage a MQ autorizations.

  Here is an example on how you should use this:

      mq_authorization { "group/mymqgroup->MYQM1/qmgr/self":
        ensure    => 'present',
        authority => ['allmqi', 'dlt', 'chg', 'dsp', 'ctrl', 'system'],
      }

  DESC

  ensurable

  map_titles_to_attributes([%r{((.*)/(.*)->(.*)/(.*)/(.*))}, [:name, :entity_type, :entity, :qmgr, :mq_type, :profile]])

  to_get_raw_resources do
    information = running_queue_managers.flat_map do |qmgr, _status|
      output = dmpmqaut("-m #{qmgr}").to_s.split('- - - - - - - -')
      output.collect { |e| [qmgr.to_s, e.to_s] }
    end
    information.collect { |e| [:qmgr, :output].zip(e).to_h }
  end

  on_create do
    apply
  end

  on_modify do
    apply
  end

  def apply
    when_running { [:setmqaut, "-m #{qmgr} -t #{mq_type} #{profile_value} #{entity_string}", {}] }
  end

  on_destroy do
    when_running { [:setmqaut, "-m #{qmgr} -t #{mq_type} #{profile_value} #{entity_string} -remove", {}] }
  end

  parameter :name
  parameter :qmgr
  parameter :profile
  parameter :mq_type
  parameter :entity
  parameter :entity_type

  property  :authority

  def entity_string
    case entity_type.to_s
    when 'group' then "-g #{entity}"
    when 'principal' then "-p #{entity}"
    else
      fail "#{entity_type} is invalid. Must be either group or principal."
    end
  end

  def profile_value
    case profile
    when 'self' then ''
    else
      "-n '#{profile}'"
    end
  end
end
