#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:authority, :array_matching => :all) do
  include EasyType
  include EasyType::ArrayProperty

  desc <<-DESC
  The authority given to specfied user or group on specfied object.

  You **MUST** specfify the indivdual authorities. The generic authorities

  - all
  - alladm
  - allmqi
  - system

  Are **NOT** supported at this point in time.
  DESC

  validate do |value|
    super(value)
    unsupported_generic_authorisations = %w[all alladm allmqi]
    fail "Generic authorities #{unsupported_generic_authorisations.join(',')} are not supported. Please specify individual authorities." if \
      unsupported_generic_authorisations.include?(value) && resource[:ensure].to_s == 'present'
  end

  to_translate_to_resource do |raw_resource|
    raw_resource[:output].scan(/authority:\s+(.*)/).flatten.first.to_s.split
  end

  on_apply do
    current_value = provider.authority == :absent ? [] : provider.authority
    to_be_removed = current_value - should
    to_be_added   = should - current_value
    array_value   = to_be_added.collect { |e| "+#{e}" } + to_be_removed.collect { |e| "-#{e}" }
    array_value.join(' ')
  end
  data_type('Optional[Variant[String,Array[String[1]]]]')
end
