#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:affinity, :parent => PuppetX::EnterpriseModules::Mq::ChannelProperty) do
  desc <<-DESC
  Use the channel affinity attribute when client applications connect multiple times using the same queue manager name. With the attribute, you can choose whether the client uses the same client channel definition for each connection. This attribute is intended to be used when multiple applicable channel definitions are available.
  Valid values are:
  - PREFERRED The first connection in a process reading a client channel definition table (CCDT) creates a list of applicable definitions. The list is based on the weightings, with any applicable CLNTWGHT (0) definitions first and in alphabetic order. Each connection in the process attempts to connect using the first definition in the list. If a connection is unsuccessful the next definition is used. Unsuccessful non- CLNTWGHT (0) definitions are moved to the end of the list. CLNTWGHT (0) definitions remain at the start of the list and are selected first for each connection. For C, C++ and .NET (including fully managed .NET) clients the list is updated if the CCDT was modified since the list was created. Each client process with the same host name creates the same list.
  - NONE The first connection in a process reading a CCDT creates a list of applicable definitions. All connections in a process select an applicable definition based on the weighting with any applicable CLNTWGHT (0) definitions selected first in alphabetic order. For C, C++ and .NET (including fully managed .NET) clients the list is updated if the CCDT was modified since the list was created.
  For example, suppose that we had the following definitions in the CCDT:
  CHLNAME(A) QMNAME (QM1) CLNTWGHT(3)
  CHLNAME(B) QMNAME (QM1) CLNTWGHT(4)
  CHLNAME(C) QMNAME (QM1) CLNTWGHT(4)
  The first connection in a process creates its own ordered list based on the weightings. So it might, for example, create the ordered list CHLNAME(B), CHLNAME(A), CHLNAME(C).
  For AFFINITY(PREFFERED), each connection in the process attempts to connect using CHLNAME(B). If a connection is unsuccessful the definition is moved to the end of the list which now becomes CHLNAME(A), CHLNAME(C), CHLNAME(B). Each connection in the process then attempts to connect using CHLNAME(A).
  For AFFINITY(NONE), each connection in the process attempts to connect using one of the three definitions selected at random based on the weightings.
  If sharing conversations is enabled with a non-zero channel weighting and AFFINITY(NONE), multiple connections do not have to share an existing channel instance. They can connect to the same queue manager name using different applicable definitions rather than sharing an existing channel instance.
  DESC

  newvalues('PREFERRED', 'NONE')
  data_type("Optional[Enum['PREFERRED', 'NONE']]")
end
