#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:conname, :parent => PuppetX::EnterpriseModules::Mq::ChannelProperty) do
  quote_values true
  desc <<-DESC
  Connection name.
  For CLUSRCVR channels, CONNAME relates to the local queue manager, and for other channels it relates to the target queue manager.
  [z/OS]On z/OS, CONNAME is mandatory for CLUSRCVR channels. In addition, whether you specify CONNAME, or the name is generated for you, the CONNAME produced must be a valid connection name for the local queue manager, otherwise the full repository is not able to make a connection back to the local queue manager.
  [z/OS]On z/OS, the maximum length of the string is 48 characters.
  On distributed platforms, the maximum length of the string is 264 characters
  A workaround to the 48 character limit might be one of the following suggestions:
  Set up your DNS servers so that you use, for example, host name of myserver instead of myserver.location.company.com, ensuring you can use the short host name.
  Use IP addresses.
  Specify CONNAME as a comma-separated list of names of machines for the stated TRPTYPE. Typically only one machine name is required. You can provide multiple machine names to configure multiple connections with the same properties. The connections are usually tried in the order they are specified in the connection list until a connection is successfully established. The order is modified for clients if the CLNTWGHT attribute is provided. If no connection is successful, the channel attempts the connection again, as determined by the attributes of the channel. With client channels, a connection-list provides an alternative to using queue manager groups to configure multiple connections. With message channels, a connection list is used to configure connections to the alternative addresses of a multi-instance queue manager.
  CONNAME is required for channels with a channel type ( CHLTYPE ) of SDR, RQSTR, CLNTCONN, and CLUSSDR. It is optional for SVR channels, and for CLUSRCVR channels of TRPTYPE(TCP), and is not valid for RCVR or SVRCONN channels.
  Providing multiple connection names in a list was first supported in IBM WebSphere MQ Version 7.0.1. It changes the syntax of the CONNAME parameter. Earlier clients and queue managers connect using the first connection name in the list, and do not read the rest of the connection names in the list. In order for the earlier clients and queue managers to parse the new syntax, you must specify a port number on the first connection name in the list. Specifying a port number avoids problems when connecting to the channel from a client or queue manager that is running at a level earlier than IBM WebSphere MQ Version 7.0.1.
  On AIX, HP-UX, IBM i, Linux, Solaris, and Windows platforms, the TCP/IP connection name parameter of a cluster-receiver channel is optional. If you leave the connection name blank, IBM MQ generates a connection name for you, assuming the default port and using the current IP address of the system. You can override the default port number, but still use the current IP address of the system. For each connection name leave the IP name blank, and provide the port number in parentheses; for example:
  (1415)
  The generated CONNAME is always in the dotted decimal (IPv4) or hexadecimal (IPv6) form, rather than in the form of an alphanumeric DNS host name.
  Tip
  If you are using any of the special characters in your connection name (for example, parentheses) you must enclose the string in single quotation marks.
  The value you specify depends on the transport type ( TRPTYPE ) to be used:
  LU62
  [z/OS]On z/OS, there are two forms in which to specify the value:
  Logical unit name
  The logical unit information for the queue manager, comprising the logical unit name, TP name, and optional mode name. Logical unit name can be specified in one of three forms:
  Form	Example
  luname	IGY12355
  luname/TPname	IGY12345/APING
  luname/TPname/modename	IGY12345/APINGD/#INTER
  For the first form, the TP name and mode name must be specified for the TPNAME and MODENAME parameters; otherwise these parameters must be blank.
  Note
  For CLNTCONN channels, only the first form is allowed.
  Symbolic name
  The symbolic destination name for the logical unit information for the queue manager, as defined in the side information data set. The TPNAME and MODENAME parameters must be blank.
  Note
  For CLUSRCVR channels, the side information is on the other queue managers in the cluster. Alternatively, it can be a name that a channel auto-definition exit can resolve into the appropriate logical unit information for the local queue manager.
  The specified or implied LU name can be that of a VTAM generic resources group.
  On AIX, HP-UX, IBM i, Linux, Solaris, and Windows , CONNAME is the name of the CPI-C communications side object. Alternatively, if the TPNAME is not blank, CONNAME is the fully qualified name of the partner logical unit [z/OS]; see Configuration parameters for an LU 6.2 connection.
  NetBIOS
  A unique NetBIOS name (limited to 16 characters).
  SPX
  The 4-byte network address, the 6-byte node address, and the 2-byte socket number. These values must be entered in hexadecimal, with a period separating the network and node addresses. The socket number must be enclosed in brackets, for example:
  CONNAME('0a0b0c0d.804abcde23a1(5e86)')
  TCP
  Either the host name, or the network address of the remote machine (or the local machine for CLUSRCVR channels). This address can be followed by an optional port number, enclosed in parentheses.
  If the CONNAME is a host name, the host name is resolved to an IP address.
  The IP stack used for communication depends on the value specified for CONNAME and the value specified for LOCLADDR. See LOCLADDR for information about how this value is resolved.
  [z/OS]On z/OS, the connection name can include the IP_name of an z/OS dynamic DNS group or a Network Dispatcher input port. Do not include the IP_name or input port for channels with a channel type ( CHLTYPE ) of CLUSSDR.
  On AIX, HP-UX, Linux, IBM i, Solaris, Windows[z/OS], and z/OS, you do not always need to specify the network address of your queue manager. If you define a channel with a channel type ( CHLTYPE ) of CLUSRCVR that is using TCP/IP, IBM MQ generates a CONNAME for you. It assumes the default port and uses the current IPv4 address of the system. If the system does not have an IPv4 address, the current IPv6 address of the system is used.
  Note
  If you are using clustering between IPv6 -only and IPv4 -only queue managers, do not specify an IPv6 network address as the CONNAME for CLUSRCVR channels. A queue manager that is capable only of IPv4 communication is unable to start a CLUSSDR channel definition that specifies the CONNAME in IPv6 hexadecimal form. Consider, instead, using host names in a heterogeneous IP environment.
  DESC
  data_type('Optional[String[1]]')
end
