#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:hbint, :parent => PuppetX::EnterpriseModules::Mq::ChannelProperty) do
  include EasyType::Mungers::Integer
  include EasyType::Validators::Integer

  desc <<-DESC
  HBINT specifies the approximate time between heartbeat flows sent by a message channel agent (MCA). The flows are sent when there are no messages on the transmission queue.
  Heartbeat flows unblock the receiving MCA, which is waiting for messages to arrive or for the disconnect interval to expire. When the receiving MCA is unblocked, it can disconnect the channel without waiting for the disconnect interval to expire. Heartbeat flows also free any storage buffers that are allocated for large messages. They also close any queues that are left open at the receiving end of the channel.
  The value is in seconds and must be in the range 0 - 999999. A value of zero means that no heartbeat flows are to be sent. The default value is 300. To be most useful, the value needs to be less than the disconnect interval value.
  For SVRCONN and CLNTCONN channels, heartbeats can flow from both the server side as well as the client side independently. If no data is transferred across the channel during the heartbeat interval, the CLNTCONN MQI agent sends a heartbeat flow. The SVRCONN MQI agent responds to it with another heartbeat flow. The flows happen irrespective of the state of the channel. For example, irrespective of whether it is inactive while making an API call, or is inactive waiting for client user input. The SVRCONN MQI agent is also capable of initiating a heartbeat to the client, again irrespective of the state of the channel. The SVRCONN and CLNTCONN MQI agents are prevented from heart beating to each other at the same time. The server heartbeat is flowed if no data is transferred across the channel for the heartbeat interval plus 5 seconds.
  On SVRCONN and CLNTCONN channels, heartbeats flow only when a server MCA is waiting for an MQGET command with the WAIT option specified. The server MCA issues an MQGET on behalf of a client application that issues an MQGET.
  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,999999]]]")
end
