#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:kaint, :parent => PuppetX::EnterpriseModules::Mq::ChannelProperty) do
  include EasyType::Mungers::Integer
  include EasyType::Validators::Integer

  def munge(value)
    return if value == 'AUTO'

    super
  end

  def validate(value)
    return if value == 'AUTO'

    super
  end

  desc <<-DESC
  The value passed to the communications stack for keepalive timing for this channel.
  For this attribute to be effective, TCP/IP keepalive must be enabled both in the queue manager and in TCP/IP.
  [z/OS]On z/OS, enable TCP/IP keepalive in the queue manager by issuing the ALTER QMGR TCPKEEP(YES) command. If the TCPKEEP queue manager parameter is NO, the value is ignored, and the keepalive facility is not used.
  On distributed platforms, TCP/IP keepalive is enabled when the KEEPALIVE=YES parameter is specified in the TCP stanza. Modify the TCP stanza in the distributed queuing configuration file, qm.ini, or through the IBM MQ Explorer.
  Keepalive must also be switched on within TCP/IP itself. Refer to your TCP/IP documentation for information about configuring keepalive. On AIX, use the no command. On HP-UX, use the ndd command. On Windows, edit the registry.
  [z/OS]On z/OS, update your TCP/IP PROFILE data set and add or change the INTERVAL parameter in the TCPCONFIG section.
  [z/OS]Although this parameter is available on all platforms, its setting is implemented only on z/OS.
  On distributed platforms, you can access and modify the parameter, but it is only stored and forwarded; there is no functional implementation of the parameter. This functionality is useful in a clustered environment where a value set in a cluster-receiver channel definition on Solaris, for example, flows to (and is implemented by) z/OS queue managers that are in, or join, the cluster.
  On distributed platforms, if you need the functionality provided by the KAINT parameter, use the Heartbeat Interval ( HBINT ) parameter, as described in HBINT.
  ( integer )
  The KeepAlive interval to be used, in seconds, in the range 1 through 99999.
  0
  The value used is that specified by the INTERVAL statement in the TCP profile configuration data set.
  AUTO
  The KeepAlive interval is calculated based upon the negotiated heartbeat value as follows:
  If the negotiated HBINT is greater than zero, keepalive interval is set to that value plus 60 seconds.
  If the negotiated HBINT is zero, the keepalive value used is that specified by the INTERVAL statement in the TCP/IP PROFILE configuration data set.
  If AUTO is specified for KAINT, and it is a server-connection channel, the TCP INTERVAL value is used instead for the keepalive interval.
  In this case, KAINT is zero in DISPLAY CHSTATUS; it would be non-zero if an integer had been coded instead of AUTO.
  This parameter is valid for all channel types. It is ignored for channels with a TRPTYPE other than TCP or SPX.
  DESC
  data_type("Optional[Variant[Enum['absent','AUTO'],Integer]]")
end
