#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:locladdr, :parent => PuppetX::EnterpriseModules::Mq::ChannelProperty) do
  quote_values true
  desc <<-DESC
  LOCLADDR is the local communications address for the channel. Use this parameter if you want a channel to use a particular IP address, port, or port range for outbound communications. LOCLADDR might be useful in recovery scenarios where a channel is restarted on a different TCP/IP stack. LOCLADDR is also useful to force a channel to use an IPv4 or IPv6 stack on a dual-stack system. You can also use LOCLADDR to force a channel to use a dual-mode stack on a single-stack system.
  This parameter is valid only for channels with a transport type ( TRPTYPE ) of TCP. If TRPTYPE is not TCP, the data is ignored and no error message is issued.
  The value is the optional IP address, and optional port or port range used for outbound TCP/IP communications. The format for this information is as follows:
  LOCLADDR([ip-addr][(low-port[,high-port])][,[ip-addr][(low-port[,high-port])]])
  The maximum length of LOCLADDR, including multiple addresses, is MQ_LOCAL_ADDRESS_LENGTH.
  If you omit LOCLADDR, a local address is automatically allocated.
  Note, that you can set LOCLADDR for a C client using the Client Channel Definition Table (CCDT).
  All the parameters are optional. Omitting the ip-addr part of the address is useful to enable the configuration of a fixed port number for an IP firewall. Omitting the port number is useful to select a particular network adapter without having the identify a unique local port number. The TCP/IP stack generates a unique port number.
  Specify [,[ip-addr][(low-port[,high-port])]] multiple times for each additional local address. Use multiple local addresses if you want to specify a specific subset of local network adapters. You can also use [,[ip-addr][(low-port[,high-port])]] to represent a particular local network address on different servers that are part of a multi-instance queue manager configuration.
  ip-addr
  ip-addr is specified in one of three forms:
  IPv4 dotted decimal
  For example 192.0.2.1
  IPv6 hexadecimal notation
  For example 2001:DB8:0:0:0:0:0:0
  Alphanumeric host name form
  For example WWW.EXAMPLE.COM
  low-port and high-port
  low-port and high-port are port numbers enclosed in parentheses.
  The following table shows how the LOCLADDR parameter can be used:
  Table 3. Examples of how the LOCLADDR parameter can be used
  LOCLADDR	Meaning
  9.20.4.98	Channel binds to this address locally
  9.20.4.98, 9.20.4.99	Channel binds to either IP address. The address might be two network adapters on one server, or a different network adapter on two different servers in a multi-instance configuration.
  9.20.4.98(1000)	Channel binds to this address and port 1000 locally
  9.20.4.98(1000,2000)	Channel binds to this address and uses a port in the range 1000 - 2000 locally
  (1000)	Channel binds to port 1000 locally
  (1000,2000)	Channel binds to port in range 1000 - 2000 locally
  This parameter is valid only for channels with a channel type ( CHLTYPE ) of SDR, SVR, RQSTR, CLNTCONN, CLUSSDR, OR CLUSRCVR.
  On CLUSSDR channels, the IP address and port to which the outbound channel binds, is a combination of fields. It is a concatenation of the IP address, as defined in the LOCLADDR parameter, and the port range from the cluster cache. If there is no port range in the cache, the port range defined in the LOCLADDR parameter is used.
  [z/OS]This port range does not apply to z/OS systems.
  Even though this parameter is similar in form to CONNAME, it must not be confused with it. The LOCLADDR parameter specifies the characteristics of the local communications, whereas the CONNAME parameter specifies how to reach a remote queue manager.
  When a channel is started, the values specified for CONNAME and LOCLADDR determine the IP stack to be used for communication; see Table 3 and Local Address ( LOCLADDR ).
  If the TCP/IP stack for the local address is not installed or configured, the channel does not start and an exception message is generated.
  [z/OS]For example, on z/OS systems, the message is "CSQO015E: Command issued but no reply received." The message indicates that the connect() request specifies an interface address that is not known on the default IP stack. To direct the connect() request to the alternative stack, specify the LOCLADDR parameter in the channel definition as either an interface on the alternative stack, or a DNS host name. The same specification also works for listeners that might not use the default stack. To find the value to code for LOCLADDR, run the NETSTAT HOME command on the IP stacks that you want to use as alternatives.
  DESC
  data_type('Optional[String[1]]')
end
