#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:sharecnv, :parent => PuppetX::EnterpriseModules::Mq::ChannelProperty) do
  include EasyType::Mungers::Integer
  include EasyType::Validators::Integer

  desc <<-DESC
  Specifies the maximum number of conversations that can be sharing each TCP/IP channel instance. A SHARECNV value of:
  - 1 Specifies no sharing of conversations over a TCP/IP channel instance. Client heart beating is available whether in an MQGET call or not. Read ahead and client asynchronous consumption are also available, and channel quiescing is more controllable.
  - 0 Specifies no sharing of conversations over a TCP/IP channel instance.

  The value must be in the range zero through 999999999.
  This parameter is valid only for channels with a channel type ( CHLTYPE ) of CLNTCONN or SVRCONN. If the CLNTCONN SHARECNV value does not match the SVRCONN SHARECNV value, the lower of the two values is used. This parameter is ignored for channels with a transport type ( TRPTYPE ) other than TCP.
  All the conversations on a socket are received by the same thread.
  High SHARECNV limits have the advantage of reducing queue manager thread usage. If many conversations sharing a socket are all busy, there is a possibility of delays. The conversations contend with one another to use the receiving thread. In this situation, a lower SHARECNV value is better.
  The number of shared conversations does not contribute to the MAXINST or MAXINSTC totals.
  Note
  You should restart the client for this change to take effect.
  DESC
  data_type("Optional[Variant[Enum['absent'],Integer[0,999999999]]]")
end
