#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:chckclnt, :parent => PuppetX::EnterpriseModules::Mq::Property) do
  desc <<-DESC
  Specifies whether the connection that matches this rule and is being allowed in with USERSRC(CHANNEL) or USERSRC(MAP), must also specify a valid user ID and password. The password cannot contain single quotation marks ( ' ).
  REQDADM
  A valid user ID and password are required for the connection to be allowed if you are using a privileged user ID.
  Any connections using a non-privileged user ID are not required to provide a user ID and password. The user ID and password are checked against the user repository details provided in an authentication information object and supplied on ALTER QMGR in the CONNAUTH field. If no user repository details are provided, so that user ID and password checking are not enabled on the queue manager, the connection is not successful.

  [z/OS]This option is not valid on z/OS platforms.

  REQUIRED
  A valid user ID and password are required for the connection to be allowed. The password cannot contain single quotation marks ( ' ).
  The user ID and password are checked against the user repository details provided in an authentication information object and supplied on ALTER QMGR in the CONNAUTH field. If no user repository details are provided, so that user ID and password checking are not enabled on the queue manager, the connection is not successful.

  ASQMGR
  In order for the connection to be allowed, it must meet the connection authentication requirements defined on the queue manager.
  If the CONNAUTH field provides an authentication information object, and the value of CHCKCLNT is REQUIRED, the connection fails unless a valid user ID and password are supplied. If the CONNAUTH field does not provide an authentication information object, or the value of CHCKCLNT is not REQUIRED, the user ID and password are not required.

  Attention
  If you select REQUIRED or REQADM on Multiplatforms and you have not set the CONNAUTH field on the queue manager, or if the value of CHCKCLNT is NONE, the connection fails. On Multiplatforms, you receive message AMQ9793. On z/OS, you receive message CSQX793E.
  This parameter is valid only with TYPE(USERMAP), TYPE(ADDRESSMAP), and TYPE(SSLPEERMAP) and only when USERSRC is not set to NOACCESS. It only applies to inbound connections which are SVRCONN channels.
  Example rules that use this attribute:
  Anything in the defined network can use an asserted user ID if a valid password is supplied:

  SET CHLAUTH('*.SVRCONN') +
      TYPE(ADDRESSMAP) ADDRESS('192.0.2.*') +
      USERSRC(CHANNEL) CHCKCLNT(REQUIRED)copy to clipboard

  This rule ensures that SSL authentication must succeed before processing client authentication according to the policy set at the queue manager:

  SET CHLAUTH('SSL.APP1.SVRCONN') +
      TYPE(SSLPEERMAP) SSLPEER('CN="Steve Smith", L="BankA"') +
      MCAUSER(SSMITH) CHCKCLNT(ASQMGR)

  DESC
  newvalues(
    'REQDADM',
    'REQUIRED',
    'ASQMGR'
  )
  data_type("Optional[Enum['REQDADM',
  'REQUIRED',
  'ASQMGR']]")
end
