#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_key_db) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage a MQ key database.

  Here is an example on how you should use this:

      mq_key_db {'/var/mqm/keys/test_db_1.kdb':
        ensure   => 'present',
        stashed  => true,
        password => 'verysecret'
      }

  DESC

  ensurable

  to_get_raw_resources do
    []
  end

  on_prefetch do |resources, provider_class|
    resources.each do |name, properties|
      next unless File.exist?(name.to_s)

      resource = { name => properties }.merge(:ensure => :present)
      resources[name].provider = provider_class.new(resource)
    end
  end

  validate do
    fail "Parameter 'genpw' and 'password' are mutual exlusive, use only one." if genpw && password
  end

  on_create do
    options = []
    options << '-strong' if strong
    options << '-genpw' if genpw
    options << "-length #{length}" if length
    options << '-stash' if stashed
    options << "-pw #{password}" if password
    Puppet.debug runmqakm("-keydb -create -type #{db_type} -db #{name} #{options.join(' ')}")
  end

  on_modify do
    fail "Modification of key database #{name} is not supported."
  end

  on_destroy do
    options = []
    options << "-pw #{password}" if password
    Puppet.debug runmqakm("-keydb -delete -db #{name}  #{options.join(' ')}")
  end

  def extension
    case db_type
    when 'cms', 'kdb'
      'kdb'
    when 'pkcs12', 'p12'
      'p12'
    end
  end

  parameter :name

  parameter :password
  parameter :db_type
  parameter :stashed
  parameter :genpw
  parameter :strong
  parameter :length
end
