#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_listener) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage a MQ listener.

  Here is an example on how you should use this:
      mq_listener { 'IIB10QM/SYSTEM.DEFAULT.LISTENER.TCP':
        ensure  => 'present',
        backlog => '0',
        control => 'MANUAL',
        port    => '0',
        trptype => 'TCP',
      }

  DESC

  ensurable

  map_titles_to_attributes([%r{((.*)/(.*))}, [:name, :qmgr, :listener]])

  to_get_raw_resources do
    listeners = []
    running_queue_managers.collect do |qmgr, status|
      next unless status == 'Running'

      listeners_on(qmgr).collect do |listener|
        output = runmqsc("display listener('#{listener}')", :qmgr => qmgr)
        listeners << { :name => listener, :qmgr => qmgr, :output => output }
      end
    end
    listeners
  end

  validate do
    fail 'property trptype is required' if trptype.nil? && self[:ensure] == :present
  end

  on_create do
    [:runmqsc, "define listener('#{listener}') trptype(#{trptype})", { :qmgr => qmgr }]
  end

  on_modify do
    [:runmqsc, "alter listener ('#{listener}') trptype(#{trptype})", { :skip_without_properties => true, :qmgr => qmgr }]
  end

  on_destroy do
    runmqsc("stop listener('#{listener}')", :qmgr => qmgr) if provider.status == 'running'
    [:runmqsc, "delete listener ('#{listener}')", { :qmgr => qmgr }]
  end

  parameter :name
  parameter :qmgr
  parameter :listener

  property :adapter
  property :trptype
  property :backlog
  property :commands
  property :control
  property :descr
  property :ipaddr
  property :loclname
  property :ntbnames
  property :port
  property :sessions
  property :socket
  property :tpname
  property :status # Needs to be the last one.
end
