#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:status) do
  include EasyType
  include PuppetX::EnterpriseModules::Mq::Commands

  desc <<-DESC
    The status of the Listener.

    Here is an example on how to use this:

        mq_listener { 'IIB10QM/SYSTEM.DEFAULT.LISTENER.TCP':
          ensure  => 'present',
          ...
          status  => 'running',
          ...
        }

    This will define the listener and directly start it.

  DESC

  defaultto(:running)
  newvalues(:stopped, :running)
  data_type('Optional[Enum["stopped", "running"]]')
  to_translate_to_resource do |raw_resource|
    qmgr     = raw_resource[:qmgr]
    listener = raw_resource[:name]
    # rubocop: disable Style/RescueStandardError
    begin
      raw_value = runmqsc("display lsstatus ('#{listener}') all", :qmgr => qmgr)
      raw_value.scan(/STATUS\((\S+)\)/).flatten.first.downcase
    rescue
      'stopped'
    end
    # rubocop: enable Style/RescueStandardError
  end

  on_modify do
    case value.to_sym
    when :stopped
      runmqsc("stop listener('#{resource.listener}')", :qmgr => resource.qmgr)
    when :running
      runmqsc("start listener('#{resource.listener}')", :qmgr => resource.qmgr)
    else
      fail 'invalid status found'
    end
    nil
  end
  after_create do
    case value.to_sym
    when :stopped
      # default w're already stopped so we do nothing
    when :running
      runmqsc("start listener('#{resource.listener}')", :qmgr => resource.qmgr)
    else
      fail 'invalid status found'
    end
    nil
  end
end
