#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:connauth, :parent => PuppetX::EnterpriseModules::Mq::MgrProperty) do
  include PuppetX::EnterpriseModules::Mq::Commands

  quote_values      true
  allow_empty_value true # An empty value actualy has meaning

  desc <<-DESC
  The name of an authentication information object that is used to provide the location of user ID and password authentication. If CONNAUTH is blank, no user ID and password checking is done by the queue manager. The maximum length of the string is MQ_AUTH_INFO_NAME_LENGTH.
  Only authentication information objects with type IDPWOS or IDPWLDAP can be specified; other types result in an error message when the OAM (on UNIX, Linux, and Windows platforms)[z/OS] or the security component (on z/OS platforms) reads the configuration. Changes to this configuration, or the object to which it refers, take effect when a REFRESH SECURITY TYPE(CONNAUTH) command is issued.
  If you leave CONNAUTH blank, and attempt to connect to a channel that has either REQDADM[z/OS] (on platforms other than z/OS ) or REQUIRED set in the CHCKCLNT field, the connection fails.
  DESC
  data_type('Optional[String[1]]')
  after_modify do
    update_security
  end

  after_create do
    update_security
  end

  def update_security
    Puppet.debug('refreshing security after change.')
    runmqsc('refresh security type(connauth)', :qmgr => resource.name)
  end
end
