#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:status) do
  include EasyType
  include PuppetX::EnterpriseModules::Mq::Commands

  desc <<-DESC
  The status of the Queue Manager.
  DESC

  defaultto('Running')
  newvalues('Starting',
            'Running',
            'Stopped',
            'Running as standby',
            'Running elsewhere',
            'Quiescing',
            'Ending immediately',
            'Ending pre-emptively',
            'Ended normally',
            'Ended immediately',
            'Ended unexpectedly',
            'Ended pre-emptively',
            'Status not available')
  data_type("Optional[Enum['Starting',
            'Running',
            'Stopped',
            'Running as standby',
            'Running elsewhere',
            'Quiescing',
            'Ending immediately',
            'Ending pre-emptively',
            'Ended normally',
            'Ended immediately',
            'Ended unexpectedly',
            'Ended pre-emptively',
            'Status not available']]")
  # rubocop: disable Naming/MethodParameterName
  def insync?(is)
    case should.to_sym
    when :Running
      ['Starting', 'Running', 'Running as standby'].include?(is)
    when :Stopped
      ['Stopped', 'Quiescing', 'Ending immediately', 'Ending pre-emptively', 'Ended normally', 'Ended immediately', 'Ended unexpectedly', 'Ended pre-emptively', 'Status not available'].include?(is)
    else
      fail 'Use status \'Running\' or \'Stopped\' as a state.'
    end
  end
  # rubocop: enable Naming/MethodParameterName

  on_modify do
    case value.to_sym
    when :Stopped
      resource.stop_qm
    when :Running
      resource.start_qm
    else
      fail 'Use status \'Running\' or \'Stopped\' as a state.'
    end
    nil
  end
  after_create do
    case value.to_sym
    when :Stopped
      endmqm resource[:name]
    when :Running
      # default w're already stopped so we do nothing
    else
      fail 'Use status \'Running\' or \'Stopped\' as a state.'
    end
    nil
  end

  to_translate_to_resource do |raw_resource|
    raw_resource[:status]
  end
end
