#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_queue) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage a MQ queue.

  Here is an example on how you should use this with QTYPE in the name:

      mq_queue { 'QM1/QLOCAL/EM_TEST':
        ensure   => 'present',
        acctq    => 'QMGR',
        bothresh => '0',
        clwlprty => '4',
        clwlrank => '1',
        clwluseq => 'QMGR',
        defbind  => 'OPEN',
        defpresp => 'SYNC',
        defprty  => '0',
        defpsist => 'NO',
        defreada => 'NO',
        defsopt  => 'SHARED',
        distl    => 'NO',
        get      => 'ENABLED',
        maxdepth => '5000',
        maxmsgl  => '4194304',
        monq     => 'QMGR',
        msgdlvsq => 'PRIORITY',
        npmclass => 'NORMAL',
        propctl  => 'COMPAT',
        put      => 'ENABLED',
        qdepthhi => '80',
        qdepthlo => '20',
        qdphiev  => 'DISABLED',
        qdploev  => 'DISABLED',
        qdpmaxev => 'ENABLED',
        qsvciev  => 'NONE',
        qsvcint  => '999999999',
        retintvl => '999999999',
        scope    => 'QMGR',
        statq    => 'QMGR',
        trigdpth => '1',
        trigmpri => '0',
        trigtype => 'FIRST',
        usage    => 'NORMAL',
      }

  Here is an deprecated example on how you should use this:

      mq_queue { 'QM1/EM_TEST':
        ensure   => 'present',
        acctq    => 'QMGR',
        bothresh => '0',
        clwlprty => '4',
        clwlrank => '1',
        clwluseq => 'QMGR',
        defbind  => 'OPEN',
        defpresp => 'SYNC',
        defprty  => '0',
        defpsist => 'NO',
        defreada => 'NO',
        defsopt  => 'SHARED',
        distl    => 'NO',
        get      => 'ENABLED',
        maxdepth => '5000',
        maxmsgl  => '4194304',
        monq     => 'QMGR',
        msgdlvsq => 'PRIORITY',
        npmclass => 'NORMAL',
        propctl  => 'COMPAT',
        put      => 'ENABLED',
        qdepthhi => '80',
        qdepthlo => '20',
        qdphiev  => 'DISABLED',
        qdploev  => 'DISABLED',
        qdpmaxev => 'ENABLED',
        qsvciev  => 'NONE',
        qsvcint  => '999999999',
        qtype    => 'QLOCAL',
        retintvl => '999999999',
        scope    => 'QMGR',
        statq    => 'QMGR',
        trigdpth => '1',
        trigmpri => '0',
        trigtype => 'FIRST',
        usage    => 'NORMAL',
      }


  DESC

  ensurable

  map_titles_to_attributes([
                             %r{((.*)/(.*)/(.*))}, [:name, :qmgr, :qtype, :queue],
                             %r{((.*)/(.*))}, [:name, :qmgr, :queue]
                           ])

  to_get_raw_resources do
    queues = []
    running_queue_managers.collect do |qmgr, status|
      next unless status == 'Running'

      queues_on(qmgr).collect do |queue, qtype|
        output = runmqsc("display queue('#{queue}')", :qmgr => qmgr)
        queues << { :name => name, :queue => queue, :qtype => qtype, :qmgr => qmgr, :output => output }
      end
    end
    queues
  end

  validate do
    fail 'property qtype is required' if qtype.nil? && self[:ensure] == :present
  end

  on_create do
    when_running { [:runmqsc, "define #{qtype} ('#{queue}')", { :qmgr => qmgr }] }
  end

  on_modify do
    when_running { [:runmqsc, "alter #{qtype} ('#{queue}')", { :qmgr => qmgr }] }
  end

  on_destroy do
    when_running { [:runmqsc, "delete #{qtype} ('#{queue}')", { :qmgr => qmgr }] }
  end

  parameter :name
  parameter :qmgr
  parameter :queue
  parameter :qtype

  property :acctq
  property :boqname
  property :bothresh
  property :clchname
  property :clusnl
  property :cluster
  property :clwlprty
  property :clwlrank
  property :clwluseq
  property :custom
  property :defbind
  property :defpresp
  property :defprty
  property :defpsist
  property :defreada
  property :defsopt
  property :deftype
  property :descr
  property :distl
  property :get
  property :initq
  property :like
  property :maxdepth
  property :maxmsgl
  property :monq
  property :msgdlvsq
  property :npmclass
  property :process
  property :propctl
  property :put
  property :qdepthhi
  property :qdepthlo
  property :qdphiev
  property :qdploev
  property :qdpmaxev
  property :qsvciev
  property :qsvcint
  property :retintvl
  property :rname
  property :rqmname
  property :scope
  property :share
  property :noshare
  property :statq
  property :target
  property :targq
  property :targtype
  property :trigdata
  property :trigdpth
  property :trigger
  property :notrigger
  property :trigmpri
  property :trigtype
  property :usage
  property :xmitq
end
