#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:deftype, :parent => PuppetX::EnterpriseModules::Mq::QueueProperty) do
  include EasyType::Mungers::Upcase

  desc <<-DESC
  Queue definition type.
  This parameter is supported only on model queues. Valid values are:
  - PERMDYN A permanent dynamic queue is created when an application issues an MQOPEN MQI call with the name of this model queue specified in the object descriptor ( MQOD). A permanent dynamic queue is created when an application issues an MQOPEN API call with the name of this model queue specified in the object descriptor ( MQOD). The dynamic queue has a disposition of SHARED.
  - TEMPDYN A temporary dynamic queue is created when an application issues an MQOPEN API call with the name of this model queue specified in the object descriptor ( MQOD).

  Do not specify this value for a model queue definition with a DEFPSIST parameter of YES.
  If you specify this option, do not specify INDXTYPE ( MSGTOKEN ).
  DESC
  newvalues('PERMDYN', 'TEMPDYN')
  data_type("Optional[Enum['PERMDYN', 'TEMPDYN']]")
  #
  # Because this property is only allowed on QMODEL ques we do not return its value
  # when we have a different queue type. Somehow MQ does this.
  #
  def self.translate_to_resource(raw_resource, resource)
    value = raw_resource[:output].scan(/#{name.upcase}\((.*?)\)/).flatten.first
    return nil if (value && value == ' ') || resource[:qtype] != 'QMODEL'

    value
  end
end
