#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_subscription) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage a MQ topic.

  Here is an example on how you should use this:

      mq_subscription { 'QUEUENAME/SUBNAME':
        ensure   => 'present',
        topicstr => 'b_topic',
        dest     => 'QUEUENAME',
      }

      mq_subscription {'QM1/SUB1':
        ensure   => 'present',
        dest     => 'SYSTEM.DEFAULT.REMOTE.QUEUE',
        topicstr => 'SYSTEM.DEFAULT.TOPIC'
      }

  DESC

  ensurable

  map_titles_to_attributes([%r{((.*?)/(.*))}, [:name, :qmgr, :subscription]])

  to_get_raw_resources do
    subcriptions = []
    running_queue_managers.collect do |qmgr, status|
      next unless status == 'Running'

      subscriptions_on(qmgr).collect do |_subscription_id, subscription_name|
        output = runmqsc("display sub('#{subscription_name}')", :qmgr => qmgr)
        subcriptions << { :name => subscription_name, :subscription => subscription_name, :qmgr => qmgr, :output => output }
      end
    end

    subcriptions
  end

  validate do
    # fail 'property dest is required'     if dest.nil? && self[:ensure] == :present
    # fail 'property topicstr is required' if topicstr.nil? && self[:ensure] == :present
  end

  on_create do
    when_running { [:runmqsc, "define sub('#{subscription}')", { :qmgr => qmgr }] }
  end

  on_modify do
    when_running { [:runmqsc, "alter sub('#{subscription}')", { :qmgr => qmgr }] }
  end

  on_destroy do
    when_running { [:runmqsc, "delete sub('#{subscription}')", { :qmgr => qmgr }] }
  end

  # Name parameters
  parameter :name
  parameter :qmgr
  parameter :subscription

  # Required properties
  property :dest
  property :topicstr

  # Optional properties
  property :destqmgr
  property :expiry
  property :pubacct
  property :pubappid
  property :subuser

  # Optional parameters
  parameter :psprop
  parameter :pubprty
  parameter :replace
  parameter :reqonly
  parameter :selector
  parameter :subscope
  parameter :topicobj
  parameter :varuser
  parameter :wschema
end
