#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_topic) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage a MQ topic.

  Here is an example on how you should use this:

      mq_topic { 'QM1/EM_TEST_TOPIC':
        ensure   => 'present',
        topicstr => 'b_topic',
        defprty  => '5',
        defpsist => 'ASPARENT',
        dursub   => 'ASPARENT',
        mcast    => 'ASPARENT',
        npmsgdlv => 'ASPARENT',
        pmsgdlv  => 'ASPARENT',
        proxysub => 'FIRSTUSE',
        pub      => 'ASPARENT',
        pubscope => 'ASPARENT',
        sub      => 'ASPARENT',
        subscope => 'ASPARENT',
        ttype    => 'LOCAL',
        usedlq   => 'ASPARENT',
        wildcard => 'PASSTHRU',
      }
  DESC

  ensurable

  map_titles_to_attributes([%r{((.*)/(.*))}, [:name, :qmgr, :topic]])

  to_get_raw_resources do
    topics = []
    running_queue_managers.collect do |qmgr, status|
      next unless status == 'Running'

      topics_on(qmgr).collect do |topic, type|
        output = runmqsc("display topic('#{topic}')", :qmgr => qmgr)
        topics << { :name => topic, :type => type, :qmgr => qmgr, :output => output }
      end
    end
    topics
  end

  validate do
    fail 'property topicstr is required' if topicstr.nil? && self[:ensure] == :present
  end

  on_create do
    when_running { [:runmqsc, "define topic('#{topic}') topicstr('#{topicstr}')", { :qmgr => qmgr }] }
  end

  on_modify do
    when_running { [:runmqsc, "alter topic ('#{topic}')", { :qmgr => qmgr }] }
  end

  on_destroy do
    when_running { [:runmqsc, "delete topic ('#{topic}')", { :qmgr => qmgr }] }
  end

  parameter :name
  parameter :qmgr
  parameter :topic

  property :topicstr
  property :ttype
  property :cmdscope
  property :like
  property :cluster
  property :comminfo
  property :custom
  property :defprty
  property :defpsist
  property :defpresp
  property :descr
  property :dursub
  property :mcast
  property :mdurmdl
  property :mndurmdl
  property :npmsgdlv
  property :pmsgdlv
  property :proxysub
  property :pub
  property :pubscope
  property :sub
  property :subscope
  property :usedlq
  property :wildcard
end
