#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'puppet_x/enterprisemodules/mq/core'

Puppet::Type.newtype(:mq_web) do
  include PuppetX::EnterpriseModules::Mq::Type
  def self.module_name
    'mq_config'
  end

  desc <<-DESC
  This resource allows you to manage the MQ Web package. This is a singleton resource.
  So there is always only one resource available on the system and it is called `mqweb`.
  Here is an example on how you should use this:

      mq_web { 'mqweb':
        ensure                                   => 'present',
        http_host                                => 'localhost',
        http_port                                => -1,
        https_port                               => 9443,
        ltpa_cookie_name                         => 'LtpaToken2_${env.MQWEB_LTPA_SUFFIX}',
        ltpa_expiration                          => 120,
        max_msg_trace_file_size                  => 200,
        max_msg_trace_files                      => 5,
        max_trace_file_size                      => 20,
        max_trace_files                          => 10,
        mq_console_autostart                     => true,
        mq_rest_autostart                        => false,
        mq_rest_cors_max_age_in_seconds          => 0,
        mq_rest_csrf_validation                  => true,
        mq_rest_gateway_enabled                  => true,
        mq_rest_messaging_enabled                => true,
        mq_rest_mft_enabled                      => false,
        mq_rest_mft_reconnect_timeout_in_minutes => 30,
        mq_rest_request_timeout                  => 30,
        secure_ltpa                              => true,
        status                                   => 'stopped',
        trace_spec                               => '*=info',
      }


  DESC

  ensurable

  to_get_raw_resources do
    #
    # This is only a single resource on the system, it's name ALWAYS mqweb.
    #
    output = dspmqweb('status', :allowed_exits => [1])
    output << dspmqweb('properties -a')
    [{ :output => output }]
  end

  on_create do
    fail 'You cannot create a resource of mq_web. Internal error.'
  end

  on_modify do
    [:setmqweb, 'properties', { :skip_without_properties => true }]
  end

  on_destroy do
    fail 'You cannot destroy a resource of mq_web. Internal error.'
  end

  parameter :name

  property :status
  property :http_host
  property :http_port
  property :https_port
  property :ltpa_cookie_name
  property :ltpa_expiration
  property :max_msg_trace_file_size
  property :max_msg_trace_files
  property :max_trace_file_size
  property :max_trace_files
  property :mq_console_autostart
  property :mq_rest_autostart
  property :mq_rest_cors_allowed_origins
  property :mq_rest_cors_max_age_in_seconds
  property :mq_rest_csrf_validation
  property :mq_rest_gateway_enabled
  property :mq_rest_gateway_qmgr
  property :mq_rest_messaging_enabled
  property :mq_rest_mft_coordination_qmgr
  property :mq_rest_mft_enabled
  property :mq_rest_mft_reconnect_timeout_in_minutes
  property :mq_rest_request_timeout
  property :secure_ltpa
  property :trace_spec
end
