#
# See the file "LICENSE" for the full license governing this code.
#
module PuppetX
  module EnterpriseModules
    module Mq
      #
      # Generic class for MQ property
      #
      class Property < Puppet::Property
        include EasyType

        def self.allow_empty_value(value = nil)
          @allow_empty_value = value unless value.nil?
          @allow_empty_value
        end

        def self.quote_values(value = nil)
          value ? @quote_values = value : (@quote_values || false)
        end

        def self.match_all?
          array_matching == :all
        end

        def self.translate_to_resource(raw_resource, _resource)
          value = raw_resource[:output].scan(/\s#{name.upcase}\((.*?)\)[\s\n]/m).flatten.first
          value = value ? value.delete("\n") : nil
          return value if allow_empty_value && value && value == ' '
          return nil if value && value == ' '
          return value.split(',').collect(&:strip) if value && match_all?

          value
        end
        # rubocop: enable

        on_apply do
          if value && match_all? && self.class.quote_values
            actual_value = value.collect { |e| "'#{e}'" }.join(',')
            "#{name}(#{actual_value})"
          elsif value && match_all? && !self.class.quote_values
            actual_value = value.join(',')
            "#{name}(#{actual_value})"
          elsif self.class.quote_values
            "#{name}('#{value}')"
          else
            "#{name}(#{value})"
          end
        end
      end
    end
  end
end
