#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/mq/command'
require 'tempfile'

module PuppetX
  module EnterpriseModules
    module Mq
      # docs
      class RunmqscCommand < PuppetX::EnterpriseModules::Mq::Command
        def initialize(options = {})
          super(:runmqsc, options, [:os_user, :password, :timeout, :qmgr, :allowed_exits])
          @qmgr          = options.fetch(:qmgr) { fail 'No qmgr option specfied.' }
          @allowed_exits = options.fetch(:allowed_exits) { [] }
        end

        # @nodoc
        # @private
        def runmqsc(arguments, options = {})
          runmqsc = PuppetX::EnterpriseModules::Mq::RunmqscCommand.new(options)
          runmqsc.execute arguments
        end

        def command_string(_arguments = '')
          kernel = Facter.value(:kernel)
          case kernel
          when 'windows'
            "\"C:\\Program Files\\IBM\\MQ\\bin\\setmqenv.cmd\" -s &&  #{@command} < #{@command_file} #{@qmgr}"
          when 'Linux', 'AIX', 'SunOS'
            ". #{@mq_path}/setmqenv -s; #{@command} < #{@command_file} #{@qmgr}"
          else
            fail "#{kernel} is not supported at this point in time."
          end
        end

        def execute(arguments)
          command_file = Tempfile.new(['runmqsc', '.runmqsc'])
          command_file.write(arguments)
          command_file.close
          FileUtils.chown(@os_user, nil, command_file.path)
          FileUtils.chmod(0o600, command_file.path)
          FileUtils.chown(@os_user, nil, command_file.path)
          FileUtils.chmod(0o600, command_file.path)
          @command_file = command_file.path
          options = { :failonfail => true, :combine => true, :uid => @os_user }
          value = ''
          within_time(@timeout) do
            begin
              Puppet.debug "Executing #{@command} command: #{arguments} as #{os_user}"
              value = Puppet::Util::Execution.execute(command_string(arguments), options)
            rescue Puppet::ExecutionFailure => e
              exit_status = e.message.scan(/returned (\d+):/).first.first.to_i
              raise unless @allowed_exits.include?(exit_status)

              Puppet.debug "Allowed error #{e.message}"
            end
          end
          Puppet.debug value
          value
        end
      end
    end
  end
end
